# encoding: utf-8
#
# Alipay決済 決済要求サンプル
#

#
# MDKへパスを通す
#
require './MdkRuby/tgMdk/lib/tg_mdk'
require './MdkRuby/tgMdk/lib/tg_mdk/mdk_dto'

#-------------------------------------------------------
# 取引ID
#-------------------------------------------------------
@order_id = "dummy" + Time.now.to_i.to_s

#-------------------------------------------------------
# 金額
# 通貨がCNYの場合は、100以上の値の指定が必須
#-------------------------------------------------------
@amount = "10"

#-------------------------------------------------------
# 通貨
# "JPY"：日本円、"CNY"：中国元
#-------------------------------------------------------
@currency = "JPY"

#-------------------------------------------------------
# 決済種別
# "0"：オンライン決済、"1"：バーコード決済(店舗スキャン型)、"2"：バーコード決済(消費者スキャン型)
#-------------------------------------------------------
@pay_type = "0"

#-------------------------------------------------------
# ユーザ識別コード
# 決済種別がバーコード決済(店舗スキャン型)の場合は指定必須
# 決済種別がオンライン決済、バーコード決済(消費者スキャン型)の場合は指定不可
#-------------------------------------------------------
@identity_code = "1234567890"

#-------------------------------------------------------
# 商品名
#-------------------------------------------------------
@commodity_name = "新製品"

#-------------------------------------------------------
# 商品詳細
# 決済種別がオンライン決済、バーコード決済(消費者スキャン型)の場合は指定任意
# 決済種別がバーコード決済(店舗スキャン型)の場合は指定不可
#-------------------------------------------------------
@commodity_description = "新製品詳細"

#-------------------------------------------------------
# 商品ID
# 決済種別がバーコード決済(消費者スキャン型)、かつ、商品詳細を指定する場合は指定必須
# 決済種別がオンライン決済、バーコード決済(店舗スキャン型)の場合は指定不可
#-------------------------------------------------------
@commodity_id = "newItemId"

#-------------------------------------------------------
# 決済成功時URL
# 決済種別がオンライン決済の場合は指定必須
# 決済種別がバーコード決済(店舗スキャン型)、バーコード決済(消費者スキャン型)の場合は指定不可
#-------------------------------------------------------
@success_url = "http://127.0.0.1/web/alipay/authorize/authorize_result"

#-------------------------------------------------------
# 決済エラー時URL
# 決済種別がオンライン決済の場合は指定必須
# 決済種別がバーコード決済(店舗スキャン型)、バーコード決済(消費者スキャン型)の場合は指定不可
#-------------------------------------------------------
@error_url = "http://127.0.0.1/web/alipay/authorize/authorize_result"

#-------------------------------------------------------
# レスポンスタイプ
# 決済種別がバーコード決済(店舗スキャン型)の場合は指定可能
# 決済種別がオンライン決済、バーコード決済(消費者スキャン型)の場合は指定不可
# "0" : 取引確定時にレスポンスを返却する。
# "1" : 即時にレスポンスを返却する。
#-------------------------------------------------------
@response_type = "0"


#==========================================================================
# 要求電文パラメータ値の指定
#==========================================================================
@request_data = Veritrans::Tercerog::Mdk::AlipayAuthorizeRequestDto.new
@request_data.order_id= @order_id.to_s
@request_data.amount= @amount.to_s
@request_data.currency= @currency.to_s
@request_data.pay_type= @pay_type.to_s
@request_data.commodity_name= @commodity_name.to_s
if @request_data.pay_type.eql?("0")
  @request_data.commodity_description= @commodity_description.to_s
  @request_data.success_url= @success_url.to_s
  @request_data.error_url= @error_url.to_s
elsif @request_data.pay_type.eql?("1")
  @request_data.identity_code= @identity_code.to_s
  @request_data.response_type = @response_type.to_s
elsif @request_data.pay_type.eql?("2")
  @request_data.commodity_description= @commodity_description.to_s
  @request_data.commodity_id= @commodity_id.to_s
end

#==========================================================================
# 実施
#==========================================================================
tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
@response_data = tran.execute(@request_data)

#
# 結果コード取得
#
@txn_status = @response_data.mstatus
#
# 詳細コード取得
#
@txn_result_code = @response_data.v_result_code
#
# エラーメッセージ取得
#
@error_message = @response_data.merr_msg


#==========================================================================
# 結果表示
#==========================================================================
# 成功
if "success" == @txn_status
  puts "...Transaction Successfully Complete"
  puts "[Status]: #{@txn_status}"
  puts "[Result Code]: #{@txn_result_code}"
  puts "[Order ID]: #{@response_data.order_id}"
  if @request_data.pay_type.eql?("1") || @request_data.pay_type.eql?("2")
    puts "[Cust Txn]: #{@response_data.cust_txn}"
    puts "[Center Trade ID]: #{@response_data.center_trade_id}"
  end
  if @request_data.pay_type.eql?("1")
    puts "[Pay Time JP]: #{@response_data.pay_time_jp}"
    puts "[Pay Time CN]: #{@response_data.pay_time_cn}"
    puts "[Buyer Charged Amount Cny]: #{@response_data.buyer_charged_amount_cny}"
  elsif @request_data.pay_type.eql?("2")
    puts "[QR Code]: #{@response_data.qr_code}"
    puts "[QR Code Img Url]: #{@response_data.qr_code_img_url}"
    puts "[QR Code Small Img Url]: #{@response_data.qr_code_small_img_url}"
    puts "[QR Code Large Img Url]: #{@response_data.qr_code_large_img_url}"
  end
end
# ペンディング
if "pending" == @txn_status
  puts "...Transaction Pending"
  puts "[Status]: #{@txn_status}"
  puts "[Message]: #{@error_message}"
  puts "[Result Code]: #{@txn_result_code}"
  puts "[Order ID]: #{@response_data.order_id}"
  puts "Check log file for more information"
end
# 失敗
if "failure" == @txn_status
  puts "...Transaction Failure"
  puts "[Status]: #{@txn_status}"
  puts "[Message]: #{@error_message}"
  puts "[Result Code]: #{@txn_result_code}"
  puts "[Order ID]: #{@response_data.order_id}"
  puts "Check log file for more information"
end

#puts @response_data.to_string
