# encoding: utf-8
#
# 電子マネー決済 返金要求サンプル
#

#
# MDKへパスを通す
#
require './MdkRuby/tgMdk/lib/tg_mdk'
require './MdkRuby/tgMdk/lib/tg_mdk/mdk_dto'

#-------------------------------------------------------
# 決済方式
#
# サイバーEdy : edy-pc
# モバイルEdy : edy-mobile
# モバイルEdyダイレクト : edy-direct
# モバイルSuicaメール決済 : suica-mobile-mail
# モバイルSuicaアプリ決済 : suica-mobile-app
# Suicaインターネット決済メール連携 : suica-pc-mail
# Suicaインターネット決済アプリ連携 : suica-pc-app
# WAON モバイルアプリ決済 : waon-mobile
# WAON PaSoRi決済 : waon-pc
#-------------------------------------------------------
@service_option_type = "edy-mobile"

#-------------------------------------------------------
# 取引ID
#-------------------------------------------------------
@order_id =  "dummy" +  Time.now.to_i.to_s

#-------------------------------------------------------
# 返金依頼金額  <= 決済金額
#-------------------------------------------------------
@request_amount =  "100"

#-------------------------------------------------------
# オーダー種別
# 返金：refund
# 新規返金: refund_new
#-------------------------------------------------------
@order_kind = "refund"

#-------------------------------------------------------
# 返金対象取引ID
#-------------------------------------------------------
@refund_order_id =  "change_order_id"

#-------------------------------------------------------
# 決済期限（Suica）
#-------------------------------------------------------
@settlement_limit = (Time.now + 24*60*60*10).strftime("%Y%m%d%H%M%S").to_s

#-------------------------------------------------------
# 画面タイトル
#-------------------------------------------------------
@screen_title = "For Mobile Suica"


#==========================================================================
# 要求電文パラメータ値の指定
#==========================================================================
@request_data = Veritrans::Tercerog::Mdk::EmRefundRequestDto.new
@request_data.service_option_type = @service_option_type.to_s
@request_data.order_id = @order_id.to_s
@request_data.refund_order_id = @refund_order_id.to_s
@request_data.order_kind = @order_kind.to_s
@request_data.amount = @request_amount.to_s

if @service_option_type.to_s.start_with?("suica")
  # Suica決済の場合
  @request_data.settlement_limit = @settlement_limit.to_s
  @request_data.screen_title = @screen_title.to_s

elsif "waon-pc" == @service_option_type.to_s
  # WAON PaSoRi決済の場合

  #== サンプルのためダミーURLを設定 ==#
  @request_data.success_url = 'http://127.0.0.1/web/PaymentMethodSelect?status=success'
  @request_data.failure_url = 'http://127.0.0.1/web/PaymentMethodSelect?status=failure'
  @request_data.cancel_url = 'http://127.0.0.1/web/PaymentMethodSelect?status=cancel'
end


#==========================================================================
# 実施
#==========================================================================
tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
@response_data = tran.execute(@request_data)

#
# 結果コード取得
#
@txn_status = @response_data.mstatus
#
# 詳細コード取得
#
@txn_result_code = @response_data.v_result_code
#
# エラーメッセージ取得
#
@error_message = @response_data.merr_msg


#==========================================================================
# 結果表示
#==========================================================================
# 成功
if "success" == @txn_status
  puts "...Transaction Successfully Complete"
  puts "[Status]: #{@txn_status}"
  puts "[Result Code]: #{@txn_result_code}"
  puts "[Order ID]: #{@response_data.order_id}"
end
# ペンディング
if "pending" == @txn_status
  puts "...Transaction Pending"
  puts "[Status]: #{@txn_status}"
  puts "[Message]: #{@error_message}"
  puts "[Result Code]: #{@txn_result_code}"
  puts "[Order ID]: #{@response_data.order_id}"
  puts "Check log file for more information"
end
# 失敗
if "failure" == @txn_status
  puts "...Transaction Failure"
  puts "[Status]: #{@txn_status}"
  puts "[Message]: #{@error_message}"
  puts "[Result Code]: #{@txn_result_code}"
  puts "[Order ID]: #{@response_data.order_id}"
  puts "Check log file for more information"
end

#puts @response_data.to_string
