# encoding: utf-8
#
# PayNowId 決済（3D認証有り）同時会員入会要求サンプル
#

#
# MDKへパスを通す
#
require './MdkRuby/tgMdk/lib/tg_mdk'
require './MdkRuby/tgMdk/lib/tg_mdk/mdk_dto'

#-------------------------------------------------------
# オプションタイプ
# 1. 本人認証サービスのみ                    : mpi-none
# 2. 完全認証                                : mpi-complete
# 3. 通常認証（カード会社リスク負担）        : mpi-company
# 4. 通常認証（カード会社、加盟店リスク負担）: mpi-merchant
#-------------------------------------------------------
@service_option_type = "mpi-none"

#-------------------------------------------------------
# 取引ID
#-------------------------------------------------------
@order_id = "dummy" + Time.now.to_i.to_s

#-------------------------------------------------------
# 同時売上実施有無
#-------------------------------------------------------
@with_capture = "false"

#-------------------------------------------------------
# 支払金額
#-------------------------------------------------------
@payment_amount = "5"

#-------------------------------------------------------
# カード番号
#-------------------------------------------------------
# @card_number = "4111-1111-1111-1111"

#-------------------------------------------------------
# カード有効期限 MM/YY
#-------------------------------------------------------
# @card_expire = "12/16"

#-------------------------------------------------------
# トークン
#-------------------------------------------------------
@token = "0a812412-682c-4dad-8a5d-720caf23bca0";

#-------------------------------------------------------
# HTTP User-Agent（消費者ブラウザ）
# （実際はアプリケーションサーバから取得）
#-------------------------------------------------------
@http_user_agent = "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)"

#-------------------------------------------------------
# HTTP Accept（消費者ブラウザ）
# （実際はアプリケーションサーバから取得）
#-------------------------------------------------------
@http_accept = "text/*;q=0.3, text/html;q=0.7"

#-------------------------------------------------------
# 会員ID
#-------------------------------------------------------
@account_id = "TestAccountId"

#-------------------------------------------------------
# 課金グループID
#-------------------------------------------------------
@group_id = "TestGroupId"

#-------------------------------------------------------
# 課金開始日
#-------------------------------------------------------
@start_date = (Time.now + 24*60*60*30).strftime("%Y%m%d").to_s

#-------------------------------------------------------
# 課金開始日
#-------------------------------------------------------
@end_date = (Time.now + 24*60*60*3000).strftime("%Y%m%d").to_s

#-------------------------------------------------------
# 都度／初回課金金額
#-------------------------------------------------------
@one_time_amount = "25"

#-------------------------------------------------------
# 継続課金金額
#-------------------------------------------------------
@recurring_amount = "10"


#==========================================================================
# 要求電文パラメータ値の指定
#==========================================================================
@request_data = Veritrans::Tercerog::Mdk::MpiAuthorizeRequestDto.new
@request_data.service_option_type = @service_option_type.to_s
@request_data.order_id = @order_id.to_s
@request_data.with_capture = @with_capture.to_s
@request_data.amount = @payment_amount.to_s
# @request_data.card_number = @card_number.to_s
# @request_data.card_expire = @card_expire.to_s
@request_data.token = @token.to_s
@request_data.http_user_agent = @http_user_agent.to_s
@request_data.http_accept = @http_accept.to_s
@request_data.account_id = @account_id.to_s
@request_data.group_id = @group_id.to_s
@request_data.start_date = @start_date.to_s
@request_data.end_date = @end_date.to_s
@request_data.one_time_amount = @one_time_amount.to_s
@request_data.recurring_amount = @recurring_amount.to_s


#==========================================================================
# 実施
#==========================================================================
tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
@response_data = tran.execute(@request_data)

#
# 結果コード取得
#
@txn_status = @response_data.mstatus
#
# 詳細コード取得
#
@txn_result_code = @response_data.v_result_code
#
# エラーメッセージ取得
#
@error_message = @response_data.merr_msg

unless @response_data.pay_now_id_response.nil?
    pay_now_id_response = @response_data.pay_now_id_response
    #
    # PayNowIDステータス取得
    #
    @pay_now_id_status = pay_now_id_response.status
    #
    # PayNowID処理番号取得
    #
    @pay_now_id_proc_id = pay_now_id_response.process_id
    #
    # PayNowIDメッセージ取得
    #
    @pay_now_id_message = pay_now_id_response.message
end


#==========================================================================
# 結果表示
#==========================================================================
# pay_now_id_status が null の場合
if @pay_now_id_status.nil?
    puts "[Status]: #{@txn_status}"
    puts "[Message]: #{@error_message}"
    puts "[PayNowId Status]: I do not know the status because of pay_now_id_response is null."
    puts "[PayNowId Message]: I do not know the status because of pay_now_id_response is null."
    puts "[Result Code]: #{@txn_result_code}"
    puts "[PayNowId ProcessId]: I do not know the status because of pay_now_id_response is null."
    puts "[Order ID]: #{@response_data.order_id}"
    puts "[Card Number]: #{@response_data.req_card_number}"
    puts "[MPI Transaction Type]: #{@response_data.mpi_transactiontype}"
    puts "Check log file for more information"
# 成功
elsif "success" == @txn_status && "success" == @pay_now_id_status
    puts "...Transaction Successfully Complete"
    puts "[Status]: #{@txn_status}"
    puts "[PayNowId Status]: #{@pay_now_id_status}"
    puts "[Result Code]: #{@txn_result_code}"
    puts "[PayNowId ProcessId]: #{@pay_now_id_proc_id}"
    puts "[Order ID]: #{@response_data.order_id}"
    puts "[Card Number]: #{@response_data.req_card_number}"
    puts "[MPI Transaction Type]: #{@response_data.mpi_transactiontype}"
# 失敗またはペンディング
else
    puts "...Transaction Failure or Pending"
    puts "[Status]: #{@txn_status}"
    puts "[Message]: #{@error_message}"
    puts "[PayNowId Status]: #{@pay_now_id_status}"
    puts "[PayNowId Message]: #{@pay_now_id_message}"
    puts "[Result Code]: #{@txn_result_code}"
    puts "[PayNowId ProcessId]: #{@pay_now_id_proc_id}"
    puts "[Order ID]: #{@response_data.order_id}"
    puts "[Card Number]: #{@response_data.req_card_number}"
    puts "[MPI Transaction Type]: #{@response_data.mpi_transactiontype}"
    puts "Check log file for more information"
end

#puts @response_data.to_string
