# -*- encoding: utf-8 -*-

require 'openssl'

class Web::Amazonpay::AuthorizeConfirmController < ApplicationController

  #-------------------------------------------------------------------------
  # Amazon Pay 確認サンプル
  #-------------------------------------------------------------------------
  def execute

    # 取引ID
    @order_id = session[:order_id]
    
    # 金額に変更があれば更新のリクエストを実施する
    @amount = session[:amount]
    original_amount = session[:original_amount]
    @pay_redirect_url = session[:pay_redirect_url]
    
    unless @amount == original_amount
      req = Veritrans::Tercerog::Mdk::AmazonpayUpdateAuthorizeRequestDto.new
      req.order_id = @order_id.to_s
      req.amount = @amount.to_s
      
      #-------------------------------------------------------------------------
      #  実施
      #-------------------------------------------------------------------------
      tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
      res = tran.execute(req)
      @response_data = res
      @request_data = req
      
      #--------------------------------------------------------------------------
      #レスポンスの取得
      #--------------------------------------------------------------------------

      # ログ
      puts "===== Debug Log ====="
      puts "vResultCode=" + @response_data.v_result_code

      @no_header_footer = "false"
      if @response_data.mstatus.to_s == Veritrans::Tercerog::Mdk::MdkConst::SUCCESS
        @pay_redirect_url = res.pay_redirect_url
      else
        @v_result_code = res.v_result_code
        @result_order_id = res.order_id
        @mstatus = res.mstatus
        @merr_msg = res.merr_msg
        return
      end
    end
    
    if !@pay_redirect_url.nil?
      redirect_to @pay_redirect_url, :status => 301
    end
    
  end

  #-------------------------------------------------------------------------
  # 決済確認の初期表示
  #-------------------------------------------------------------------------
  def index
  
    # 取引ID
    @order_id = params[:orderId]

    # ハッシュ値のチェック
    @warning_message = check_auth_info
    
    unless @warning_message.empty?
      return
    end
    
    # 住所取得コマンドのパラメータを設定
    req = Veritrans::Tercerog::Mdk::AmazonpayGetAddressRequestDto.new
    req.order_id = @order_id.to_s
    req.add_info_resp_flag = "1"
    
    # 住所取得コマンドの実行
    res = Veritrans::Tercerog::Mdk::AmazonpayGetAddressResponseDto.new
    
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    res = tran.execute(req)
    @mstatus = res.mstatus.to_s
    @status_success = Veritrans::Tercerog::Mdk::MdkConst::SUCCESS
    
    #レスポンスの取得
    if @mstatus == Veritrans::Tercerog::Mdk::MdkConst::SUCCESS
      # 画面に表示するパラメータ
      @order_id = res.order_id
      @shipping_name = res.shipping_name
      @shipping_postal_code = res.shipping_postal_code
      @shipping_address1 = res.shipping_address1
      @shipping_address2 = res.shipping_address2
      @shipping_address3 = res.shipping_address3
      @shipping_phone = res.shipping_phone
    
      @buyer_name = res.buyer_name
      @billing_address1 = res.billing_address1
      @billing_address2 = res.billing_address2
      @billing_address3 = res.billing_address3
      @buyer_email = res.buyer_email
      @payment_preferences = res.payment_preferences
      @shipping_amount = "0"
      @amount = session[:original_amount].to_i + @shipping_amount.to_i
      session[:amount] = @amount.to_s
    
      # 住所変更などでamazon側の画面に遷移する際に必要
      @checkout_session_id = res.checkout_session_id.to_s
      
      # ダミー取引の判定用パラメータを設定
      mdk_config = Veritrans::Tercerog::Mdk::MdkConfig.instance
      @dummy_request = mdk_config[:DUMMY_REQUEST]
      
      if @dummy_request.to_i == 1
        @checkout_result_return_url = session[:pay_confirm_screen_url] + "?orderId=" + params[:orderId] + "&orderHash=" + params[:orderHash]
      end
      
      # セッションに保存
      session[:pay_redirect_url] = res.pay_redirect_url
      
    else
      # 結果画面に表示します。
      @v_result_code = res.v_result_code
      @result_order_id = res.order_id
      @mstatus = res.mstatus
      @merr_msg = res.merr_msg
    end
    
  end


  #-------------------------------------------------------------------------
  # orderHashパラメータのチェック
  #-------------------------------------------------------------------------
  private
  def check_auth_info

    conf = Veritrans::Tercerog::Mdk::MdkConfig.instance
    hash_key = conf.merchant_cc_id + params[:orderId] + conf.merchant_secret_key
    hash_value = OpenSSL::Digest::SHA1.hexdigest(hash_key)
    unless params[:orderHash] == hash_value
      return "<font color='#ff0000'><b>【パラメータ改竄】パラメータ情報が改竄されています。</b></font>"
    else
      return ""
    end
  end
  
end
