# -*- encoding: utf-8 -*-
class Web::Amazonpay::AuthorizeController < ApplicationController

  before_action :set_init

  #-------------------------------------------------------------------------
  # Amazon Pay 与信要求サンプル
  #-------------------------------------------------------------------------
  def execute
    #-------------------------------------------------------------------------
    # パラメータを取得します。
    #-------------------------------------------------------------------------
    # 取引ID
    @order_id = params[:order_id]
    # 決済金額
    @amount = params[:amount]
    # 与信方法フラグ
    @with_capture = params[:with_capture]
    # 配送先表示抑止フラグ
    @suppress_shipping_address_view = params[:suppress_shipping_address_view]
    # 注文説明
    @note_to_buyer = params[:note_to_buyer]
    # 完了時URL
    @success_url = params[:success_url]
    # キャンセル時URL
    @cancel_url = params[:cancel_url]
    # エラー時URL
    @error_url = params[:error_url]
    # 決済確認画面種別
    @pay_confirm_screen_type = params[:pay_confirm_screen_type]
    # 決済確認画面URL
    @pay_confirm_screen_url = params[:pay_confirm_screen_url]

    #-------------------------------------------------------------------------
    # 取引ID更新の場合の処理
    #-------------------------------------------------------------------------
    unless params[:update_id].blank?
      @order_id = "dummy" + Time.now.to_i.to_s
      render :action => "index"
      return
    end

    #-------------------------------------------------------------------------
    #  入力パラメータ値チェック
    #-------------------------------------------------------------------------
    @error_message = ""
    if @order_id.nil? || @order_id.empty?
      @error_message = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font><br/><br/>"
      @order_id = "dummy" + Time.now.to_i.to_s
      render :action => "index"
      return
    end
    if @amount.nil? || @amount.empty?
      @error_message = "<font color='#ff0000'><b>必須項目：決済金額が指定されていません</b></font><br/><br/>"
      render :action => "index"
      return
    end

    #-------------------------------------------------------------------------
    # 要求電文パラメータ値の指定
    #-------------------------------------------------------------------------
    req = Veritrans::Tercerog::Mdk::AmazonpayAuthorizeRequestDto.new
    req.order_id = @order_id.to_s
    req.amount = @amount.to_s
    req.with_capture = @with_capture.to_s
    req.suppress_shipping_address_view = @suppress_shipping_address_view.to_s
    req.note_to_buyer = @note_to_buyer.to_s
    req.success_url = @success_url.to_s
    req.cancel_url = @cancel_url.to_s
    req.error_url = @error_url.to_s
    req.pay_confirm_screen_type = @pay_confirm_screen_type.to_s
    req.pay_confirm_screen_url = @pay_confirm_screen_url.to_s

    #-------------------------------------------------------------------------
    #  実施
    #-------------------------------------------------------------------------
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    res = tran.execute(req)
    @response_data = res
    @request_data = req

    #--------------------------------------------------------------------------
    #レスポンスの取得
    #--------------------------------------------------------------------------

    # ログ
    puts "===== Debug Log ====="
    puts "vResultCode=" + @response_data.v_result_code

    @no_header_footer = "false"
    if @response_data.mstatus.to_s == Veritrans::Tercerog::Mdk::MdkConst::SUCCESS
      @redirect_html = res.response_contents
      
      # セッションへの保管
      session[:order_id] = @order_id.to_s
      session[:original_amount] = @amount.to_s
      session[:pay_confirm_screen_url] = @pay_confirm_screen_url.to_s
      
      if !@redirect_html.nil? && !@redirect_html.empty?
        # redirect コンテンツを返す場合、view で header/footer を表示しない
        #@no_header_footer = is_no_header_footer
        @no_header_footer = "true"
      elsif !res.redirect_url.nil?
        redirect_to res.redirect_url, :status => 301
      end
    else
      @redirect_html = ""
    end

    @v_result_code = res.v_result_code
    @result_order_id = res.order_id
    @mstatus = res.mstatus
    @merr_msg = res.merr_msg
  end

  private

  #-------------------------------------------------------------------------
  # 入力フォーム初期表示
  #-------------------------------------------------------------------------
  def set_init
    @order_id = "dummy" + Time.now.to_i.to_s
    @amount = params[:price].to_s || params[:price]
    if params[:note_to_buyer]
      @note_to_buyer = params[:note_to_buyer]
    else
      @note_to_buyer = ""
    end

    #yaml形式のconfig.ymlファイルを読み込む
    config = loadEnv4sample

    #各種URLを取得
    @success_url = config["Amazonpay"]["success_url"]
    @cancel_url  = config["Amazonpay"]["cancel_url"]
    @error_url   = config["Amazonpay"]["error_url"]
    @pay_confirm_screen_url = config["Amazonpay"]["pay_confirm_screen_url"]
  end

end
