# -*- encoding: utf-8 -*-
class Web::Carrier::AbstractTerminateController < ApplicationController

  # set_dummy_request を実行する
  # after_action では render の後に実行されるため
  before_action :set_dummy_request

  #-------------------------------------------------------------------------
  # 入力フォーム初期表示
  #-------------------------------------------------------------------------
  def index
    #yaml形式のconfig.ymlファイルを読み込む
    config = loadEnv4sample

    suffix = get_config_suffix

    #各種URLを取得
    @success_url = config["Carrier"]["success_url"+suffix]
    @cancel_url  = config["Carrier"]["cancel_url"+suffix]
    @error_url   = config["Carrier"]["error_url"+suffix]
    @push_url    = config["Carrier"]["push_url"+suffix]
  end

  #-------------------------------------------------------------------------
  # before_action で実行されるメソッド
  def set_dummy_request
    # ダミーモード判定
    mdk_config = Veritrans::Tercerog::Mdk::MdkConfig.instance
    @dummy_request = mdk_config[:DUMMY_REQUEST]

    #forceパラメータを取得し、@is_forceに設定
    @is_force = params[:force].nil? ? "false":params[:force]
    #fource == true かどうかで次のアクションが決まる
    @next_action = @is_force == "true" ? "exec_force":"execute"
  end

  #-------------------------------------------------------------------------
  # キャリア決済 継続課金終了（消費者）サンプル
  #-------------------------------------------------------------------------
  def execute
    exec_user
  end

  #-------------------------------------------------------------------------
  # キャリア決済 継続課金終了（2者間）サンプル
  #-------------------------------------------------------------------------
  def exec_force
    puts "start exec_force"
    #-------------------------------------------------------------------------
    # パラメータを取得します。
    #-------------------------------------------------------------------------
    # 取引ID
    @order_id = params[:order_id]
    # サービスオプションタイプ(キャリアの種類)を取得
    @service_option_type = params[:service_option_type]
    #プッシュURL
    @push_url = params[:push_url]
    @push_url = "" if @push_url.nil?

    # force パラメータは before_action で設定済

    #-------------------------------------------------------------------------
    #  入力パラメータ値チェック
    #-------------------------------------------------------------------------
    @error_message = ""
    if @order_id.nil? || @order_id.empty?
      @error_message = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font><br/><br/>"
      render :action => "index"
      return
    end

    #-------------------------------------------------------------------------
    #  要求電文パラメータ値の指定
    #-------------------------------------------------------------------------
    req = Veritrans::Tercerog::Mdk::CarrierTerminateRequestDto.new
    req.service_option_type = @service_option_type.to_s
    req.order_id = @order_id.to_s
    if @service_option_type == Veritrans::Tercerog::Mdk::MdkConst::CARRIER_DOCOMO ||
       @service_option_type == Veritrans::Tercerog::Mdk::MdkConst::CARRIER_SB_MATOMETE
      req.force = @is_force.to_s
    end
    unless @push_url.empty?
      req.push_url = @push_url.to_s
    end

    #-------------------------------------------------------------------------
    # コマンドを実行し、応答DTOを取得します。
    #-------------------------------------------------------------------------
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    res = tran.execute(req)

    #--------------------------------------------------------------------------
    # 結果画面に表示します。
    #--------------------------------------------------------------------------
    @result_order_id = res.order_id
    @mstatus = res.mstatus
    @v_result_code = res.v_result_code
    @merr_msg = res.merr_msg
    @terminate_datetime = res.terminate_datetime
  end

  #-------------------------------------------------------------------------
  # キャリア決済 継続課金終了（3者間）サンプル
  #-------------------------------------------------------------------------
  def exec_user
    puts "start exec_user"
    #-------------------------------------------------------------------------
    # パラメータを取得します。
    #-------------------------------------------------------------------------
    # 取引ID
    @order_id = params[:order_id]
    # サービスオプションタイプ(キャリアの種類)を取得
    @service_option_type = params[:service_option_type]
    #端末種別
    if @service_option_type == Veritrans::Tercerog::Mdk::MdkConst::CARRIER_SB_MATOMETE ||
       @service_option_type == Veritrans::Tercerog::Mdk::MdkConst::CARRIER_FLETS ||
       @service_option_type == Veritrans::Tercerog::Mdk::MdkConst::CARRIER_DOCOMO && @is_force != "true"
      @terminal_kind = params[:terminal_kind]
    end

    #決済完了時URL
    @success_url = params[:success_url]
    #決済キャンセル時URL
    @cancel_url = params[:cancel_url]
    #決済エラー時URL
    @error_url = params[:error_url]
    #プッシュURL
    @push_url = params[:push_url]

    #-------------------------------------------------------------------------
    #  入力パラメータ値チェック
    #-------------------------------------------------------------------------
    @error_message = ""
    if @order_id.nil? || @order_id.empty?
      @error_message = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font><br/><br/>"
      if @service_option_type == Veritrans::Tercerog::Mdk::MdkConst::CARRIER_AU ||
         @service_option_type == Veritrans::Tercerog::Mdk::MdkConst::CARRIER_SB_KTAI
        config = loadEnv4sample
        @success_url = config["Carrier"]["success_url"]
        @cancel_url  = config["Carrier"]["cancel_url"]
        @error_url   = config["Carrier"]["error_url"]
      end
      render :action => "index"
      return
    end

    #-------------------------------------------------------------------------
    #  要求電文パラメータ値の指定
    #-------------------------------------------------------------------------
    req = Veritrans::Tercerog::Mdk::CarrierTerminateRequestDto.new
    req.service_option_type = @service_option_type.to_s
    req.order_id = @order_id.to_s
    req.terminal_kind = @terminal_kind.to_s
    if req.service_option_type == Veritrans::Tercerog::Mdk::MdkConst::CARRIER_DOCOMO ||
       req.service_option_type == Veritrans::Tercerog::Mdk::MdkConst::CARRIER_SB_MATOMETE
      req.force = Veritrans::Tercerog::Mdk::MdkConst::FALSE
    end

    req.success_url = @success_url.to_s
    req.cancel_url = @cancel_url.to_s
    req.error_url = @error_url.to_s
    req.push_url = @push_url.to_s unless @push_url.nil?

    #-------------------------------------------------------------------------
    #  実施
    #-------------------------------------------------------------------------
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    res = tran.execute(req)
    @response_data = res
    @request_data = req

    #--------------------------------------------------------------------------
    #レスポンスの取得
    #--------------------------------------------------------------------------

    # ログ
    puts "===== Debug Log : Terminate ====="
    puts "Carrier[" + @service_option_type + "] : vResultCode=" + @response_data.v_result_code

    @no_header_footer = "false"
    if @response_data.mstatus.to_s == Veritrans::Tercerog::Mdk::MdkConst::SUCCESS
      @redirect_html = res.response_contents
      # redirect コンテンツを返す場合、view で header/footer を表示しない
      #@no_header_footer = is_no_header_footer
      @no_header_footer = "true"
      elsif !res.redirect_url.nil?
        redirect_to res.redirect_url, :status => 301
    else
      @redirect_html = ""
    end

    @v_result_code = res.v_result_code
    @result_order_id = res.order_id
    @mstatus = res.mstatus
    @merr_msg = res.merr_msg
  end

end
