# -*- encoding: utf-8 -*-
class Web::Linepay::AuthorizeController < ApplicationController

  # set_dummy_request を実行する
  # after_action では render の後に実行されるため
  before_action :set_dummy_request

  #-------------------------------------------------------------------------
  # 入力フォーム初期表示
  #-------------------------------------------------------------------------
  def index
    @order_id  = "dummy" + Time.now.to_i.to_s
    @amount    = params[:price].to_s
    @item_name = params[:item_name].to_s

    #yaml形式のconfig.ymlファイルを読み込む
    config = loadEnv4sample

    #各種URLを取得
    @success_url = config["Linepay"]["success_url"]
    @cancel_url  = config["Linepay"]["cancel_url"]
    @error_url   = config["Linepay"]["error_url"]
    @push_url    = config["Linepay"]["push_url"]
  end

  #-------------------------------------------------------------------------
  # before_action で実行されるメソッド
  def set_dummy_request
    # ダミーモード判定
    mdk_config = Veritrans::Tercerog::Mdk::MdkConfig.instance
    @dummy_request = mdk_config[:DUMMY_REQUEST]
  end

  #-------------------------------------------------------------------------
  # LINEPay 与信要求サンプル
  #-------------------------------------------------------------------------
  def execute
    #-------------------------------------------------------------------------
    # パラメータを取得します。
    #-------------------------------------------------------------------------
    # 取引ID
    @order_id = params[:order_id]
    # 支払金額
    @amount = params[:amount]
    # 与信方法
    @with_capture = params[:with_capture]
    #商品番号
    @item_id = params[:item_id]
    #商品名
    @item_name = params[:item_name]
    #商品画像URL
    @item_image_url = params[:item_image_url]
    #使用ブラウザ判定
    @check_use_browser = params[:check_use_browser]
    #アプリ起動URLスキーム
    @app_url_scheme = params[:app_url_scheme]
    #独自アプリ
    @use_original_app = params[:use_original_app]
    #packageName
    @package_name = params[:package_name]
    #決済完了時URL
    @success_url = params[:success_url]
    #決済キャンセル時URL
    @cancel_url = params[:cancel_url]
    #決済エラー時URL
    @error_url = params[:error_url]
    #決済確認方法
    @payment_confirm_type = params[:payment_confirm_type]
    #ワンタイムキー
    @one_time_key = params[:one_time_key]
    #プッシュURL
    @push_url = params[:push_url]

    #-------------------------------------------------------------------------
    # 取引ID更新の場合の処理
    #-------------------------------------------------------------------------
    unless params[:update_id].blank?
      @order_id = "dummy" + Time.now.to_i.to_s
      render :action => "index"
      return
    end

    #-------------------------------------------------------------------------
    #  入力パラメータ値チェック
    #-------------------------------------------------------------------------
    @error_message = ""
    if @order_id.nil? || @order_id.empty?
      @error_message = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font><br/><br/>"
      @order_id = "dummy" + Time.now.to_i.to_s
      render :action => "index"
      return
    end
    if @amount.nil? || @amount.empty?
      @error_message = "<font color='#ff0000'><b>必須項目：決済金額が指定されていません</b></font><br/><br/>"
      render :action => "index"
      return
    end
    # ダミーモード判定
    unless @push_url.nil? || @push_url.empty?
      mdk_config = Veritrans::Tercerog::Mdk::MdkConfig.instance
      unless mdk_config[:DUMMY_REQUEST] == Veritrans::Tercerog::Mdk::MdkConst::DUMMY_MODE_TRUE
          @error_message = "<font color='#ff0000'><b>プッシュURLはダミーモードのときにのみ指定可能です</b></font><br/><br/>"
          render :action => "index"
          return
      end
    end

    #-------------------------------------------------------------------------
    # 要求電文パラメータ値の指定
    #-------------------------------------------------------------------------
    req = Veritrans::Tercerog::Mdk::LinepayAuthorizeRequestDto.new
    req.order_id = @order_id.to_s
    req.amount = @amount.to_s
    req.with_capture = @with_capture.to_s

    req.item_id = @item_id.to_s
    req.item_name = @item_name.to_s
    req.item_image_url = @item_image_url
    req.check_use_browser = @check_use_browser.to_s
    req.app_url_scheme = @app_url_scheme
    req.use_original_app = @use_original_app
    req.package_name = @package_name
    req.success_url = @success_url.to_s
    req.cancel_url = @cancel_url.to_s
    req.error_url = @error_url.to_s
    req.one_time_key = @one_time_key.to_s
    req.payment_confirm_type = @payment_confirm_type.to_s
    req.push_url = @push_url.to_s unless @push_url.nil?

    #-------------------------------------------------------------------------
    #  実施
    #-------------------------------------------------------------------------
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    res = tran.execute(req)
    @response_data = res
    @request_data = req

    #--------------------------------------------------------------------------
    #レスポンスの取得
    #--------------------------------------------------------------------------

    # ログ
    puts "===== Debug Log ====="
    puts "vResultCode=" + @response_data.v_result_code

    @no_header_footer = "false"
    if @response_data.mstatus.to_s == Veritrans::Tercerog::Mdk::MdkConst::SUCCESS
      if !res.redirect_web_url.nil?
        redirect_to res.redirect_web_url, :status => 301
      end
    end

    @v_result_code = res.v_result_code
    @result_order_id = res.order_id
    @mstatus = res.mstatus
    @merr_msg = res.merr_msg
    @linepay_order_id = res.linepay_order_id
  end

end
