# -*- encoding: utf-8 -*-
class Web::Paynowid::Recurring::TerminateController < ApplicationController

  SESSION_KEY_RECURRING_GROUP_ITEMS = "recurring_group_items".freeze

  #-------------------------------------------------------------------------
  # 入力フォーム初期表示
  #-------------------------------------------------------------------------
  def index
    @recurring_group_items = create_recurring_group_select_items(nil, nil)
    session[SESSION_KEY_RECURRING_GROUP_ITEMS] = @recurring_group_items
    @group_id_select = ""
  end

  #-------------------------------------------------------------------------
  # 継続課金停止(カード払い)要求サンプル
  #-------------------------------------------------------------------------
  def execute
    #-------------------------------------------------------------------------
    # パラメータを取得します。
    #-------------------------------------------------------------------------
    # 会員ID
    @account_id = params[:account_id]
    # 課金グループID
    @group_id_select = params[:group_id_select]
    # 課金終了日
    @end_date = params[:end_date]
    # 課金自動終了フラグ
    @final_charge = params[:final_charge]

    # セッションから課金グループリストを取得
    @recurring_group_items = session[SESSION_KEY_RECURRING_GROUP_ITEMS]

    if !params[:get_recurring_info].blank?
      # 継続課金情報処理の場合
      get_recurring_info

    else
      # 継続課金停止処理の場合
      delete
    end
  end

  private

  #-------------------------------------------------------------------------
  # 継続課金情報取得サンプル
  #-------------------------------------------------------------------------
  def get_recurring_info
    #-------------------------------------------------------------------------
    # 必須パラメータ値チェック
    #-------------------------------------------------------------------------
    @error_message = nil
    if @account_id.nil? || @account_id.empty?
      # 会員ID
      @error_message = "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>"
    end

    unless @error_message.nil?
      # エラーが存在する場合は入力画面に戻る。
      render :action => "index"
      return
    end


    #-------------------------------------------------------------------------
    # 要求DTOを生成し、値を設定します。
    #-------------------------------------------------------------------------
    req = Veritrans::Tercerog::Mdk::RecurringGetRequestDto.new
    req.account_id = @account_id.to_s


    #-------------------------------------------------------------------------
    # コマンドを実行し、応答DTOを取得します。
    #-------------------------------------------------------------------------
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    res = tran.execute(req)


    #--------------------------------------------------------------------------
    # 結果画面に表示します。
    #--------------------------------------------------------------------------
    @mstatus = res.mstatus
    if @mstatus == "success"
      # レスポンスから継続課金グループ選択項目を生成
      account = res.pay_now_id_response.account
      @recurring_group_items = create_recurring_group_select_items(account.recurring_charge, account.card_info)
      session[SESSION_KEY_RECURRING_GROUP_ITEMS] = @recurring_group_items

      # 成功の場合は入力画面に遷移
      render :action => "index"

    else
      # それ以外の場合は結果画面に遷移
      @v_result_code = res.v_result_code
      @merr_msg = res.merr_msg

      if !res.pay_now_id_response.nil?
        @pay_now_id_proc_id = res.pay_now_id_response.process_id
        @pay_now_id_status = res.pay_now_id_response.status
      end
    end
  end

  #-------------------------------------------------------------------------
  # 継続課金停止サンプル
  #-------------------------------------------------------------------------
  def delete
    #-------------------------------------------------------------------------
    # 必須パラメータ値チェック
    #-------------------------------------------------------------------------
    @error_message = nil
    if @account_id.nil? || @account_id.empty?
      # 会員ID
      @error_message = "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>"

    elsif @group_id_select.nil? || @group_id_select.empty?
      # 課金グループID
      @error_message = "<font color='#ff0000'><b>必須項目：課金グループIDが指定されていません</b></font>"
    end

    unless @error_message.nil?
      # エラーが存在する場合は入力画面に戻る。
      render :action => "index"
      return
    end


    #-------------------------------------------------------------------------
    # 要求DTOを生成し、値を設定します。
    #-------------------------------------------------------------------------
    req = Veritrans::Tercerog::Mdk::RecurringDeleteRequestDto.new
    req.account_id = @account_id.to_s
    req.group_id = @group_id_select.to_s
    req.end_date = @end_date.to_s unless @end_date.nil?

    if @final_charge == true
      req.final_charge = "1"
    else
      req.final_charge = "0"
    end


    #-------------------------------------------------------------------------
    # コマンドを実行し、応答DTOを取得します。
    #-------------------------------------------------------------------------
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    res = tran.execute(req)


    #--------------------------------------------------------------------------
    # 結果画面に表示します。
    #--------------------------------------------------------------------------
    @v_result_code = res.v_result_code
    @merr_msg = res.merr_msg

    if !res.pay_now_id_response.nil?
      @pay_now_id_proc_id = res.pay_now_id_response.process_id
      @pay_now_id_status = res.pay_now_id_response.status
    end
  end

  #-------------------------------------------------------------------------
  # 継続課金グループ選択項目を生成する。
  #-------------------------------------------------------------------------
  def create_recurring_group_select_items(recurring_charge_array, card_info_array)

    # カードIDをキーとしたカード情報のハッシュを生成する。
    card_info_hash = {}
    unless card_info_array.nil?
      card_info_array.each do |info|
        card_info_hash[info.card_id] = info
      end
    end

    items = []
    unless recurring_charge_array.nil?
      recurring_charge_array.each do |recurring|

        # カードIDに紐付くカード情報を取得する。
        card_info = card_info_hash[recurring.card_id]
        if card_info.nil?
          items << [:"#{recurring.group_id} : ", recurring.group_id]
        else
          items << [:"#{recurring.group_id} : #{card_info.card_number} : #{card_info.card_expire}", recurring.group_id]
        end
      end
    end
    return items
  end
end
