# -*- encoding: utf-8 -*-
class Web::Saison::CaptureController < ApplicationController

  #-------------------------------------------------------------------------
  # 入力フォーム初期表示
  #-------------------------------------------------------------------------
  def index
    if "success" == params[:mstatus] then
      @order_id = params[:orderId]
      @point_balance = params[:pointBalance]
      @aqf_point_balance = params[:aqfPointBalance]
      @available_value = params[:availableValue]
      @amount = session[:amount]
      @with_capture ||= 'false'

      @re_oauth_order_id = "dummy" + Time.now.to_i.to_s
     else
      @order_id = params[:orderId]
      @mstatus = params[:mstatus]
      @v_result_code = params[:vResultCode]
      @merr_msg = URI.decode_www_form_component((/merrMsg=(.*?)&/.match(request.headers["REQUEST_URI"].to_s))[1].to_s)

      @process_name = "売上"
      @_screen = "Capture"

      render :action => 'web/saison/result/index'
    end
    load_token_api_info
  end

  #-------------------------------------------------------------------------
  # Saison決済 売上要求サンプル
  #-------------------------------------------------------------------------
  def execute
    #-------------------------------------------------------------------------
    # パラメータを取得します。
    #-------------------------------------------------------------------------
    # 取引ID
    @order_id = params[:order_id]
    # 永久不滅ウォレット残高
    @point_balance = params[:point_balance]
    # 永久不滅ポイント残高
    @aqf_point_balance = params[:aqf_point_balance]
    # 交換後利用可能バリュー
    @available_value = params[:available_value]
    # 合計決済金額
    @amount = params[:amount];
    # 永久不滅ウォレット決済金額
    @wallet_amount = params[:wallet_amount];
    # カード決済金額
    @card_amount = params[:card_amount];
    # トークン
    @token = params[:token]
    # カード取引ＩＤ
    @card_order_id = params[:card_order_id];
    # 残高再表示用取引ID
    @re_oauth_order_id = params[:re_oauth_order_id];
    # カード売上フラグ
    @with_capture = params[:with_capture];

    #-------------------------------------------------------------------------
    # 残高再表示実行
    #-------------------------------------------------------------------------
    unless params[:re_oauth].blank? then
      load_token_api_info
      redirect_to(:controller => "authorize", :action => "execute", :params => {:order_id => @re_oauth_order_id, :amount => @amount})
      return
    end


    #-------------------------------------------------------------------------
    # 必須パラメータ値チェック
    #-------------------------------------------------------------------------
    @error_message = nil
    if @order_id.blank?
      @error_message = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font><br/><br/>"

    elsif @amount.blank?
      @error_message = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font><br/><br/>"

    elsif @wallet_amount.blank?
      @error_message = "<font color='#ff0000'><b>必須項目：永久不滅ウォレット決済金額が指定されていません</b></font><br/><br/>"

    elsif @amount.present? && (not @amount =~ /^[0-9]+$/)
      @error_message = "<font color='#ff0000'><b>合計決済金額は数値で入力しなければなりません</b></font><br/><br/>"

    elsif @wallet_amount.present? && (not @wallet_amount =~ /^[0-9]+$/)
      @error_message = "<font color='#ff0000'><b>永久不滅ウォレット決済金額は数値で入力しなければなりません</b></font><br/><br/>"

    elsif @card_amount.present? && (not @card_amount =~ /^[0-9]+$/)
      @error_message = "<font color='#ff0000'><b>カード決済金額は数値で入力しなければなりません</b></font><br/><br/>"

    elsif @card_amount.blank?
      if @amount != @wallet_amount
        @error_message = "<font color='#ff0000'><b>永久不滅ウォレット決済金額とカード決済金額の合計額が合計決済金額になる必要があります</b></font><br/><br/>"
      end
    else
      total = @wallet_amount.to_i + @card_amount.to_i
      if @amount.to_i != total
        @error_message = "<font color='#ff0000'><b>永久不滅ウォレット決済金額とカード決済金額の合計額が合計決済金額になる必要があります</b></font><br/><br/>"
      end
    end

    unless @error_message.nil?
      # エラーが存在する場合は入力画面に戻る。
      load_token_api_info
      render :action => "index"
      return
    end


    #-------------------------------------------------------------------------
    # 要求DTOを生成し、値を設定します。
    #-------------------------------------------------------------------------
    req = Veritrans::Tercerog::Mdk::SaisonCaptureRequestDto.new
    req.order_id = @order_id.to_s
    req.amount = @amount.to_s
    req.wallet_amount = @wallet_amount.to_s
    req.card_amount = @card_amount.to_s
    req.card_order_id = @card_order_id.to_s
    req.with_capture = @with_capture.to_s
    if @amount.to_s != @wallet_amount.to_s
        req.token = @token.to_s
    end


    #-------------------------------------------------------------------------
    # コマンドを実行し、応答DTOを取得します。
    #-------------------------------------------------------------------------
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    res = tran.execute(req)


    #------------------------------------------------------------------------
    # 結果画面に表示します。
    #------------------------------------------------------------------------
    @result_order_id = res.order_id
    @mstatus = res.mstatus
    @v_result_code = res.v_result_code
    @merr_msg = res.merr_msg

    @card_order_id = res.card_order_id
    @card_mstatus = res.card_mstatus
    @card_v_result_code = res.card_v_result_code
    @card_merr_msg = res.card_merr_msg
    @req_card_number = res.req_card_number
    @res_auth_code = res.res_auth_code

    @process_name = "売上"
    @_screen = "Capture"

    render :template => 'web/saison/result/index'
  end

  private

  #-------------------------------------------------------------------------
  # MDKトークン設定情報を読み込む。
  #-------------------------------------------------------------------------
  def load_token_api_info
    config = loadEnv4sample
    @token_api_key = config["Token"]["token_api_key"].to_s
    @token_api_url = config["Token"]["token_api_url"].to_s
    if @token_api_url.blank?
      mdk_config = Veritrans::Tercerog::Mdk::MdkConfig.instance
      uri = URI.parse(mdk_config[:HOST_URL])
      @token_api_url = uri.to_s + "/4gtoken"
    end
  end
end
